 !-----------------------------------------------------------------------
 ! Program:   Reke1p
 ! Funkcija:  Modifikacija fajla sa profilima.
 ! Opis:      Program Reke1 koristi profile koji su UCITANI SA UZVODNOG
 !            KRAJA RACUNSKE DEONICE, NIZVODNO; ako to nije slucaj, pre
 !            koriscenja programa Reke1, ulazni fajl se mora modifikovati.
 !
 !            Smer ucitavanja profila definisan je parametrom "smerp" u
 !            ORIGINALNOM fajlu sa profilima:
 !
 !       
 !            smerp = +1:  profili su ucitani sa uzvodnog kraja, nizvodno: 
 !                         uzvodni kraj    --->          nizvodni kraj     
 !                            1   2   3    4   ...       nprof        
 !            Reke1p nista ne menja, samo se u modifikovani fajl uredno 
 !            upisu koordinate i taj fajl se, kao i originalni fajl, moze 
 !            koristiti u programu Reke1.
 !
 !
 !            smerp = -1:  profili su ucitani sa nizvodnog kraja, uzvodno: 
 !                         uzvodni kraj       <---       nizvodni kraj      
 !                            nprof     ...  4     3     2    1      
 !            Reke1p modifikuje originalni fajl tako da profil br. 1 odgovara
 !            odgovara uzvodnom kraju deonice, a profil br. nprof, nizvodnom.
 !            Modifikovani fajl se zatim koristi u programu Reke1.
 !          
 !
 ! Autor:     M. Jovanovic, okt. 1993, okt. 1999.
 ! Okruzenje: Lahey Fortran90, LF90, V.2.00a, 1995.
 !            Microsoft Fortran Power Station, V.4, 1995.
 !----------------------------------------------------------------------

  PROGRAM Reke1p
     implicit none
     character(12)          :: datu, dati, opom
     character(75)          :: text
     integer, parameter     :: maxp = 200, maxt = 50
     integer                :: nprof, smerp, ip, i, j, k
     real, dimension (maxt) :: zpom, ypom
     real                   :: dy, npom

     TYPE :: profil
        integer                :: nt   ! broj koordinatnih tacaka
        real                   :: xs   ! stacionaza (m)
        character(12)          :: oz   ! oznaka profila
        real, dimension (maxt) :: zp   ! kota dna
        real, dimension (maxt) :: yp   ! odstojanje
     END TYPE profil
     TYPE(profil), allocatable, dimension (:) :: pp

     print "(5x,A)", "Ime originalnog fajla sa profilima?   "
     read *, datu
     print "(5x,A)", "Ime modifikovanog fajla sa profilima? "
     read *, dati
     OPEN( UNIT = 1, FILE = datu, STATUS = "old"     )
     OPEN( UNIT = 2, FILE = dati, STATUS = "replace" )

     read(1, "(A)") text
     read(1, * ) nprof, smerp
     if( nprof > maxp )               stop 'Premasen broj profila   !!'
     if(smerp /= 1 .and. smerp /= -1) stop 'Smer ucitavanja profila ?!'

     ALLOCATE( pp(nprof) )

     ip = 0
     do while( ip < nprof )
        ip = ip + 1
        read(1, *)  ip, pp( ip )%xs, pp( ip )%nt, pp( ip )%oz 
        if(pp( ip )%nt > maxt) then
	   print *, ' Profil broj :', ip, pp( ip )%oz
	   stop     ' Premasen maksimalni broj tacaka !'
	else                                  ! ucitavanje koordinata
           read(1, *) ( pp( ip )%zp(j), j = 1, pp( ip )%nt )
           read(1, *) ( pp( ip )%yp(j), j = 1, pp( ip )%nt )
	endif

        do j = 1, pp( ip )%nt - 1             ! provera podataka
           dy = pp( ip )%yp(j+1) - pp( ip )%yp(j)
	   if( dy < 0. ) then
              print *, ' Profil broj :', ip, pp( ip )%oz
              stop     ' Greska u podacima! <y> ??'
           endif
        enddo
     enddo

     if( smerp == -1 ) then                   ! prenumeracija
        do k = 1, nprof / 2
           i = nprof + 1 - k
           j = nprof - i + 1
           npom = pp( j )%xs;  pp( j )%xs = pp( i )%xs;  pp( i )%xs = npom
           npom = pp( j )%nt;  pp( j )%nt = pp( i )%nt;  pp( i )%nt = npom
           opom = pp( j )%oz;  pp( j )%oz = pp( i )%oz;  pp( i )%oz = opom
           zpom = pp( j )%zp;  pp( j )%zp = pp( i )%zp;  pp( i )%zp = zpom
           ypom = pp( j )%yp;  pp( j )%yp = pp( i )%yp;  pp( i )%yp = ypom
        enddo                  
     endif

     write(2, "(A)") text     ! stampanje modifikovanog fajla
     write(2, * ) nprof
     do i = 1, nprof
        write(2, 101) i, pp( i )%xs, pp( i )%nt, pp( i )%oz
        101 format( i6, f12.3, i6, 5x, '"', A, '"' )
        write(2, "(10f8.2)" ) ( pp( i )%zp( j ), j = 1, pp( i )%nt )
        write(2, "(10f8.2)" ) ( pp( i )%yp( j ), j = 1, pp( i )%nt )
     enddo

     CLOSE( 1 ); CLOSE( 2 )
  END PROGRAM Reke1p    